@@ -6,13 +6,14 @@ except ImportError:
     from urllib2 import urlopen, Request
 
 from collections import namedtuple
+from functools import wraps
 import json
 
 from .bearing import Bearing
 from .point import Point
 
 
-Wind = namedtuple('Wind', ['direction', 'speed', 'relative_direction'])
+Wind = namedtuple('Wind', ['absolute', 'speed', 'apparent'])
 
 
 class Boatd(object):
@@ -53,20 +54,39 @@ class Boatd(object):
     @property
     def version(self):
         '''Return the version of boatd'''
-        content = self.boatd.get('/')
+        content = self.get('/')
         return content.get('boatd').get('version')
 
 
 class Boat(object):
-    '''A boat controlled by boatd'''
+    '''
+    A boat controlled by boatd
+    
+    :param auto_update: automatically update properties when they are requested.
+    '''
 
-    def __init__(self, boatd=None):
+    def __init__(self, boatd=None, auto_update=True):
         if boatd is None:
             self.boatd = Boatd()
         else:
             self.boatd = boatd
 
+        self.auto_update = auto_update
+        self._cached_boat = {}
+
+    def _auto_update(f):
+        @wraps(f)
+        def dec(self) :
+            if self.auto_update:
+                self.update()
+            return f(self)
+        return dec
+
+    def update(self):
+        self._cached_boat = self.boatd.get('/boat')
+
     @property
+    @_auto_update
     def heading(self):
         '''
         Return the current heading of the boat in degrees.
@@ -74,10 +94,11 @@ class Boat(object):
         :returns: current bearing
         :rtype: Bearing
         '''
-        content = self.boatd.get('/boat')
+        content = self._cached_boat
         return Bearing(float(content.get('heading')))
 
     @property
+    @_auto_update
     def wind(self):
         '''
         Return the direction of the wind in degrees.
@@ -85,25 +106,15 @@ class Boat(object):
         :returns: wind object containing direction bearing and speed
         :rtype: Wind
         '''
-        content = self.boatd.get('/wind')
+        content = self._cached_boat.get('wind')
         return Wind(
-            Bearing(content.get('direction')) - self.heading,
+            Bearing(content.get('absolute')),
             content.get('speed'),
-            Bearing(content.get('direction'))
+            Bearing(content.get('apparent'))
         )
 
     @property
-    def relative_wind(self):
-        '''
-        Return the direction of the wind, relative to the boat's current
-        direction.
-
-        :returns: wind direction bearing in boat coordinates
-        :rtype: Bearing
-        '''
-        return self.wind.direction
-
-    @property
+    @_auto_update
     def position(self):
         '''
         Return the current position of the boat.
@@ -111,7 +122,7 @@ class Boat(object):
         :returns: current position
         :rtype: Point
         '''
-        content = self.boatd.get('/boat')
+        content = self._cached_boat
         lat, lon = content.get('position')
         return Point(lat, lon)
 
